package org.jastadd.ros2rag.tests;

import example.ast.*;
import org.junit.jupiter.api.Test;

/**
 * Test case "example".
 *
 * @author rschoene - Initial contribution
 */
public class ExampleTest {

  @Test
  public void buildModel() {
    Model model = new Model();
    model.MqttSetHost("localhost");

    ZoneModel zoneModel = new ZoneModel();
    zoneModel.setSize(makePosition(1, 1, 1));

    IntPosition myPosition = makePosition(0, 0, 0);
    Coordinate myCoordinate = new Coordinate(myPosition);
    Coordinate leftPosition = new Coordinate(makePosition(-1, 0, 0));
    Coordinate rightPosition = new Coordinate(makePosition(1, 0, 0));

    Zone safetyZone = new Zone();
    safetyZone.addCoordinate(myCoordinate);
    safetyZone.addCoordinate(leftPosition);
    safetyZone.addCoordinate(rightPosition);
    zoneModel.addSafetyZone(safetyZone);
    model.setZoneModel(zoneModel);

    RobotArm robotArm = new RobotArm();
    robotArm.setAttributeTestSource(1);  // set initial value, no trigger

    Joint joint1 = new Joint();
    joint1.setName("joint1");
    joint1.setCurrentPosition(myPosition);

    EndEffector endEffector = new EndEffector();
    endEffector.setName("gripper");
    endEffector.setCurrentPosition(makePosition(2, 2, 3));

    robotArm.addJoint(joint1);
    robotArm.setEndEffector(endEffector);
    model.setRobotArm(robotArm);

    // add dependencies
    robotArm.addDependency1(joint1);
    robotArm.addDependency1(endEffector);
    robotArm.addDependency2(robotArm);
  }

  private static IntPosition makePosition(int x, int y, int z) {
    return IntPosition.of(x, y, z);
  }

}
